\name{SoilShear}
\Rdversion{2.15}
\alias{SoilShear}
\title{
	Shear strengths of soils
}
\description{
	Data sets covers the shear strengths from soils
}
\arguments{
  \item{cohesion}{
	a numeric for the cohesion, in kPa
}
  \item{friction angle}{
	a numeric for the inner friction angle, in degree
}
}
\details{
	The data set contains several columns : cohesion, friction angle, unit grivity, investigator, published year, soil name.
}
\value{
	Returns a matrix that contains above values for each soils included in the data set.
}
\references{
	Wu XZ. 2017. Implementing multivariate fitting and reliability analyses for geotechnical engineering problems in R. Georisk, 11(2):173-188.
}
\note{

	Please read the following references for the original data (adopted from):

	[1] Cherubini, C., 2000. Reliability evaluation of shallow foundation bearing capacity on  c-phi  soils. Canadian Geotechnical Journal, 37, 264-269. 

	[2] Forrest William S. and Orr Trevor L.L. 2010. Reliability of shallow foundations designed to Eurocode 7, Georisk: Assessment and Management of Risk for Engineered Systems and Geohazards, 4:4, 186-207. 

	[3] Hammond CJ, Hardcastle JH. 1992. Determination of values for shear strength parameters using improved methodology. Final report for cooperative agreement No 22-C-4-INT-166. US Department of Agriculture, Forest Service.

	[4] Hata Yoshiya, Ichii Koji and Tokida Ken-ichi. 2011. A probabilistic evaluation of the size of earthquake induced slope failure for an embankment, Georisk: Assessment and Management of Risk for Engineered Systems and Geohazards, DOI:10.1080/17499518.2011.604583.

	[5] Hatanaka M. and Uchida A. 1996. Empirical correlation between penetration resistance and internal friction angle of sandy soils. Soils and Foundations, 36(4):1-9.

	[6] Lumb, P. 1970. Safety factors and the probability distribution of soil strength. Can. Geotech. J., 7(3), 225-242.

	[7] Matsuo, M., and Kuroda, K., 1974. Probabilistic approach to design of embankments: Jour. Japanese Society of Soil Mechanics and Foundation Engineering, v. 14, no. 2.

	[8] Schultze E. 1971. Frequency distributions and correlations of soil properties. In Lumb, P. (ed.) Statistics and Probability in Civil Engineering (Int. Conf. Appl. Stat. Prob. Soil Struct. Eng.). Hong Kong Univ. Press, 372-387.

	[9] Parker, C., Simon, A., Thorne, C.R., 2008. The effects of variability in bank material properties on riverbank stability: Goodwin Creek, Mississippi. Geomorphology, 101, 533-543. 

  [10] Ngoc PQ. An investigation on petrophysical and geotechnical properties of soils uing multivariate statistics. Clausthal University of Technology. Germany, 2012.
}


\seealso{

	Wu X.Z. 2013. Probabilistic slope stability analysis by a copula-based sampling method. Computational Geosciences. 2013. 17(5):739-755.

	Wu X.Z. 2013. Trivariate analysis of soil ranking-correlated characteristics and its application to probabilistic stability assessments in geotechnical engineering problems. Soils and Foundations. 2013. 53(4):540-556. 

	Wu X.Z. 2015. Modelling dependence structures of soil shear strength data with bivariate copulas and applications to geotechnical reliability analysis. Soils and Foundations. 55(5):1243-1258.
}
\author{
Xingzheng
Wu \email{xingzhengwu@gmail.com}

}
\examples{
	##---- Should be DIRECTLY executable !! ----
	##--	listing data.
	data(SoilShear)
	SoilShear[["name"]]  ##column named "name"

	which(SoilShear[["name"]]=="Lumb")  ##returns a vector of the indices of x 
	which(SoilShear[["type"]]=="MBC")  ##returns a vector of the indices of x 
	SoilShear[which(SoilShear[["type"]]=="MBC"),]   
		##listing a matrix where the soil type = 'MBC'
}
\keyword{ cohesion  }
\keyword{ friction angle  }
\keyword{ gravity}


